@@ -1,6 +1,7 @@
 import heyy
 from .dbf_utils import (
     dbf2objs,
+    try_dbf2objs,
     str2objs,
     read_fields,
     compare_fields,
@@ -9,6 +10,7 @@ from .dbf_utils import (
 
 pt = heyy.pt
 dbf2objs = dbf2objs
+try_dbf2objs = try_dbf2objs
 str2objs = str2objs
 read_fields = read_fields
 compare_fields = compare_fields
